/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.k.adapter;


import org.apache.camel.CamelContext;
import org.apache.camel.ProducerTemplate;

public class Main extends org.apache.camel.main.MainSupport {
    public Main(CamelContext context) {
        this.camelContext = context;
    }

    @Override
    protected void doStart() throws Exception {
        super.doStart();
        postProcessCamelContext(camelContext);

        try {
            // if we were veto started then mark as completed
            this.camelContext.start();
        } finally {
            if (this.camelContext.isVetoStarted()) {
                completed();
            }
        }
    }

    protected void doStop() throws Exception {
        super.doStop();
        this.camelContext.stop();
    }

    @Override
    protected ProducerTemplate findOrCreateCamelTemplate() {
        return this.camelContext.createProducerTemplate();
    }

    @Override
    protected CamelContext createCamelContext() {
        return this.camelContext;
    }
}