/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.k.spring.boot.layout;

import java.io.File;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;

import org.springframework.boot.loader.tools.Layout;
import org.springframework.boot.loader.tools.Layouts;
import org.springframework.boot.loader.tools.LibraryScope;

public class Factory implements org.springframework.boot.loader.tools.LayoutFactory {
    private static final Set<LibraryScope> SCOPES = new HashSet<>(
        Arrays.asList(
            LibraryScope.COMPILE,
            LibraryScope.RUNTIME,
            LibraryScope.CUSTOM)
    );

    @Override
    public Layout getLayout(File source) {
        return new Layouts.Jar() {
            @Override
            public String getLibraryDestination(String libraryName, LibraryScope scope) {
                if (SCOPES.contains(scope)) {
                    return super.getLibraryDestination(libraryName, scope);
                }

                return null;
            }
        };
    }
}
